==> haskell-ghc-syntax-highlighter-0.0.10.0-3.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-syntax-highlighter.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghc-syntax-highlighter
version:              0.0.10.0
visibility:           public
id:                   ghc-syntax-highlighter-0.0.10.0-BPbFMngeGvZBkfH3T0xhvk
key:                  ghc-syntax-highlighter-0.0.10.0-BPbFMngeGvZBkfH3T0xhvk
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/ghc-syntax-highlighter
synopsis:             Syntax highlighter for Haskell using the lexer of GHC
description:          Syntax highlighter for Haskell using the lexer of GHC.
category:             Text
abi:                  3dafee8ca5be8c6c21a7c1215aaa53d9
exposed:              True
exposed-modules:      GHC.SyntaxHighlighter
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/ghc-syntax-highlighter-0.0.10.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/ghc-syntax-highlighter-0.0.10.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/ghc-syntax-highlighter-0.0.10.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-syntax-highlighter
hs-libraries:         HSghc-syntax-highlighter-0.0.10.0-BPbFMngeGvZBkfH3T0xhvk
depends:
    base-4.18.2.1 ghc-lib-parser-9.6.6.20240701-5tnwV8Oo0yDEfyybbFjRdd
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-ghc-syntax-highlighter/html/ghc-syntax-highlighter.haddock

haddock-html:         /usr/share/doc/haskell-ghc-syntax-highlighter/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghc-syntax-highlighter-0.0.10.0-4-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-syntax-highlighter.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghc-syntax-highlighter
version:              0.0.10.0
visibility:           public
id:                   ghc-syntax-highlighter-0.0.10.0-3EIGG4OCzod6kPhwM8pZgw
key:                  ghc-syntax-highlighter-0.0.10.0-3EIGG4OCzod6kPhwM8pZgw
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/ghc-syntax-highlighter
synopsis:             Syntax highlighter for Haskell using the lexer of GHC
description:          Syntax highlighter for Haskell using the lexer of GHC.
category:             Text
abi:                  39b0b6b9f5e1480fc3dfcb0170b8a2da
exposed:              True
exposed-modules:      GHC.SyntaxHighlighter
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/ghc-syntax-highlighter-0.0.10.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/ghc-syntax-highlighter-0.0.10.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/ghc-syntax-highlighter-0.0.10.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-syntax-highlighter
hs-libraries:         HSghc-syntax-highlighter-0.0.10.0-3EIGG4OCzod6kPhwM8pZgw
depends:
    base-4.18.2.1 ghc-lib-parser-9.6.6.20240701-5tnwV8Oo0yDEfyybbFjRdd
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-ghc-syntax-highlighter/html/ghc-syntax-highlighter.haddock

haddock-html:         /usr/share/doc/haskell-ghc-syntax-highlighter/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
